@@ -38,8 +38,10 @@ class PypiPackage:
 
     def source_url(self, version):
         name = self.archive_name(version)
-        sdist_ext = " zip" if self.is_zip_archive(version) else ""
-        return "%{pypi_source " + name + sdist_ext + "}"
+        # If it's a zip, %{pypi_source} must take all three args:
+        # name, version and zip; hence adding `version + zip`
+        zip_macro = " %{version} zip" if self.is_zip_archive(version) else ""
+        return "%{pypi_source " + name + zip_macro + "}"
 
     def version(self):
         return self.package_data["info"]["version"]
@@ -97,9 +99,9 @@ class PypiPackage:
     def project_url(self):
         try:
             return self.package_data["info"]["project_urls"]["Homepage"]
-        # It may happen that no Homepage is listed with the project
-        # In this case fall back to the safe PyPI URL
-        except KeyError:
+        # It may happen that no project_urls nor Homepage are listed with the
+        # project - in this case fall back to the safe PyPI URL
+        except (KeyError, TypeError):
             return self.package_data["info"]["package_url"]
 
     def is_zip_archive(self, version):
